{ config, ... }:
{
  imports = [
    # ./blink-cmp.nix
    # ./blink-cmp-copilot.nix
    # ./blink-cmp-dictionary.nix
    # ./blink-copilot.nix
    # ./blink-emoji.nixd
    ./bufferline.nix
    ./cmp.nix
    ./codecompanion.nix
    ./copilot.nix
    ./diffview.nix
    ./fzf-lua.nix
    ./lazydev.nix
    ./lsp.nix
    ./luasnip.nix
    ./nvim-tree.nix
    ./telescope.nix
    ./vim-signify.nix
  ];

  programs.nixvim.plugins = {
    comment.enable = true;
    fugitive.enable = true;
    gitsigns.enable = true;
    indent-blankline = {
      enable = true;
      luaConfig.post = ''
        local highlight = {
            "RainbowRed",
            "RainbowYellow",
            "RainbowBlue",
            "RainbowOrange",
            "RainbowGreen",
            "RainbowViolet",
            "RainbowCyan",
        }
        local hooks = require "ibl.hooks"
        -- create the highlight groups in the highlight setup hook, so they are reset
        -- every time the colorscheme changes
        hooks.register(hooks.type.HIGHLIGHT_SETUP, function()
            vim.api.nvim_set_hl(0, "RainbowRed", { fg = "#E06C75" })
            vim.api.nvim_set_hl(0, "RainbowYellow", { fg = "#E5C07B" })
            vim.api.nvim_set_hl(0, "RainbowBlue", { fg = "#61AFEF" })
            vim.api.nvim_set_hl(0, "RainbowOrange", { fg = "#D19A66" })
            vim.api.nvim_set_hl(0, "RainbowGreen", { fg = "#98C379" })
            vim.api.nvim_set_hl(0, "RainbowViolet", { fg = "#C678DD" })
            vim.api.nvim_set_hl(0, "RainbowCyan", { fg = "#56B6C2" })
        end)

        vim.g.rainbow_delimiters = { highlight = highlight }
        require("ibl").setup { scope = { highlight = highlight } }

        hooks.register(hooks.type.SCOPE_HIGHLIGHT, hooks.builtin.scope_highlight_from_extmark)
      '';
    };
    lightline.enable = false;
    lualine.enable = true;
    nix.enable = true;
    noice.enable = true;
    ## disable, very annoying as notifications block content and
    ## are part of the buffer rotation
    notify = {
      enable = false;
      topDown = false;
    };
    nvim-autopairs.enable = true;
    nvim-lightbulb.enable = true;
        # config = ''
        #   lua << EOF
        #   require('nvim-lightbulb').setup({
        #     float = {
        #       -- "true" causes "invalid buffer id" error
        #       enabled = false,
        #     },
        #     autocmd = {
        #       enabled = true,
        #     },
        #   })
        #   EOF
        # '';

    oil.enable = true;
    rainbow-delimiters.enable = true;
    sleuth.enable = true;
    startify.enable = config.nixvim-config.enable-startify;
    treesitter.enable = false;
    tmux-navigator.enable = true;
    trouble.enable = true;
    # ## Needed for telescope, nvim-tree, trouble, diffview, bufferline, and other plugins
    # ## Only on unstable at the moment
    web-devicons.enable = true;
    which-key.enable = true;
    yanky.enable = true;
  };
}
